from typing import List
from sqlmodel import SQLModel

from autoflow.storage.table import Table


class Database:
    def create_table(self, table_name: str, schema: SQLModel) -> Table:
        raise NotImplementedError()

    def list_tables(self, schema: SQLModel) -> List[Table]:
        raise NotImplementedError()


database = Database()



from autoflow.storage.doc_store import DocumentStore, TiDBDocumentStore
from autoflow.storage.graph_store import KnowledgeGraphStore, TiDBKnowledgeGraphStore


__all__ = [
    "DocumentStore",
    "TiDBDocumentStore",
    "KnowledgeGraphStore",
    "TiDBKnowledgeGraphStore",
]



from typing import Type

from sqlalchemy import Engine
from sqlmodel import SQLModel


class Table:
    def __init__(self, engine: Engine, schema: SQLModel):
        self._engine = engine
        self._model = schema

    def get(self, id: int):
        raise NotImplementedError

    def update(self, obj: Type[SQLModel], update: dict):
        raise NotImplementedError

    def search(self):
        raise NotImplementedError

    def delete(self):
        raise NotImplementedError



import uuid
from typing import Optional, List

from sqlalchemy import Engine
from sqlmodel import SQLModel

from autoflow.knowledge_base import KnowledgeBase
from autoflow.llms import (
    ChatModel,
    EmbeddingModel,
)
from autoflow.schema import IndexMethod
from autoflow.llms import LLMManager, default_llm_manager


class Autoflow:
    _db_engine = None
    _model_manager = None

    def __init__(
        self, db_engine: Engine, model_manager: LLMManager = default_llm_manager
    ):
        self._db_engine = db_engine
        self._model_manager = model_manager
        self._init_table_schema()

    def _init_table_schema(self):
        SQLModel.metadata.create_all(self._db_engine)

    @property
    def db_engine(self) -> Engine:
        return self._db_engine

    @property
    def llm_manager(self) -> LLMManager:
        return self._model_manager

    def create_knowledge_base(
        self,
        name: str,
        chat_model: ChatModel,
        embedding_model: EmbeddingModel,
        description: Optional[str] = None,
        index_methods: Optional[List[IndexMethod]] = None,
        id: Optional[uuid.UUID] = None,
    ) -> KnowledgeBase:
        return KnowledgeBase(
            name=name,
            description=description,
            index_methods=index_methods,
            chat_model=chat_model,
            embedding_model=embedding_model,
            id=id,
            db_engine=self._db_engine,
        )
